@@ -1,7 +1,7 @@
 package IPC::System::Options;
 
-our $DATE = '2016-10-06'; # DATE
-our $VERSION = '0.28'; # VERSION
+our $DATE = '2016-10-11'; # DATE
+our $VERSION = '0.29'; # VERSION
 
 use strict;
 use warnings;
@@ -59,7 +59,7 @@ sub _system_or_readpipe_or_run {
         die "Unknown option '$_'"
             unless /\A(
                         capture_stdout|capture_stderr|
-                        chdir|dies?|env|lang|log||max_log_output|shell|
+                        chdir|dies?|dry_run|env|lang|log||max_log_output|shell|
                         stdin # XXX: only for run()
                     )\z/x;
     }
@@ -135,7 +135,27 @@ sub _system_or_readpipe_or_run {
 
     if ($which eq 'system') {
 
-        $log->tracef("system(%s), env=%s", \@args, \%set_env) if $opts->{log};
+        if ($opts->{log} || $opts->{dry_run}) {
+            if ($opts->{log}) {
+                my $meth;
+                my $label = "";
+                if ($opts->{dry_run}) {
+                    $label = "[DRY RUN] ";
+                    $meth = "infof";
+                } else {
+                    $meth = "tracef";
+                }
+                $log->$meth("%ssystem(%s), env=%s", $label, \@args, \%set_env);
+            } else {
+                warn "[DRY RUN] system(".join(", ", @args).")\n";
+            }
+            if ($opts->{dry_run}) {
+                $exit_code = 0;
+                $res = "";
+                goto CHECK_RESULT;
+            }
+        }
+
         my $doit = sub {
             if ($opts->{shell}) {
                 # force the use of shell
@@ -156,7 +176,28 @@ sub _system_or_readpipe_or_run {
 
         $wa = wantarray;
         my $cmd = _quote(@args);
-        $log->tracef("qx(%s), env=%s", $cmd, \%set_env) if $opts->{log};
+
+        if ($opts->{log} || $opts->{dry_run}) {
+            if ($opts->{log}) {
+                my $meth;
+                my $label = "";
+                if ($opts->{dry_run}) {
+                    $label = "[DRY RUN] ";
+                    $meth = "infof";
+                } else {
+                    $meth = "tracef";
+                }
+                $log->$meth("%sreadpipe(%s), env=%s", $label, $cmd, \%set_env);
+            } else {
+                warn "[DRY RUN] readpipe($cmd)\n";
+            }
+            if ($opts->{dry_run}) {
+                $exit_code = 0;
+                $res = "";
+                goto CHECK_RESULT;
+            }
+        }
+
         my $doit = sub {
             if ($wa) {
                 $res = [`$cmd`];
@@ -199,7 +240,28 @@ sub _system_or_readpipe_or_run {
 
     } else {
 
-        $log->tracef("run(%s), env=%s", \@args, \%set_env) if $opts->{log};
+        if ($opts->{log} || $opts->{dry_run}) {
+            if ($opts->{log}) {
+                my $meth;
+                my $label = "";
+                if ($opts->{dry_run}) {
+                    $label = "[DRY RUN] ";
+                    $meth = "infof";
+                } else {
+                    $meth = "tracef";
+                }
+                $log->$meth("%srun(%s), env=%s", $label,
+                            join(", ", @args), \%set_env);
+            } else {
+                warn "[DRY RUN] run(".join(", ", @args).")\n";
+            }
+            if ($opts->{dry_run}) {
+                $exit_code = 0;
+                $res = "";
+                goto CHECK_RESULT;
+            }
+        }
+
         require IPC::Run;
         $res = IPC::Run::run(
             \@args,
@@ -304,7 +366,7 @@ IPC::System::Options - Perl's system() and readpipe/qx replacement, with options
 
 =head1 VERSION
 
-This document describes version 0.28 of IPC::System::Options (from Perl distribution IPC-System-Options), released on 2016-10-06.
+This document describes version 0.29 of IPC::System::Options (from Perl distribution IPC-System-Options), released on 2016-10-11.
 
 =head1 SYNOPSIS
 
@@ -335,6 +397,9 @@ This document describes version 0.28 of IPC::System::Options (from Perl distribu
  # log using Log::Any, die on failure
  system({log=>1, die=>1}, "blah", ...);
 
+ # chdir first before running program (and chdir back afterwards)
+ system({chdir => "/tmp", die => 1}, "some-program");
+
 Set default options for all calls (prefix each option with dash):
 
  use IPC::System::Options 'system', 'readpipe', -log=>1, -die=>1;
@@ -403,7 +468,15 @@ Capture stderr using L<Capture::Tiny>.
 =item * chdir => str
 
 Attempt to change to specified directory first and change back to the original
-directory after the command has been run.
+directory after the command has been run. This is a convenient option so you can
+do this kind of task in a single call:
+
+ {
+     my $cwd = getcwd();
+     chdir $dir or die;
+     system(...);
+     chdir $cwd or die;
+ }
 
 If the attempt to chdir before command execution fails, will die if C<die>
 option is set to true. Otherwise, C<$!> (OS error) will be set to the C<chdir()>
@@ -415,6 +488,21 @@ option is set to true. Otherwise, C<$!> will be set to the C<chdir()> error and
 C<$?> will be set to -1 only if C<$?> is zero. So if the command fails, C<$?>
 will contain the exit code of the command.
 
+=item * dry_run => bool
+
+If set to true, then will only display what would be executed to STDERR (or log
+at C<warn> level, if C<log> option is true) instead of actually executing the
+command.
+
+Will set C<$?> (child exit code) to 0.
+
+An example of how this option can be used:
+
+ system({ dry_run => $ENV{DRY_RUN} }, ...);
+
+This will allow you to run script in dry-run mode by setting environment
+variable.
+
 =back
 
 =head2 readpipe([ \%opts ], @args)
@@ -461,6 +549,10 @@ If set, will limit result length being logged. It's a good idea to set this
 
 See option documentation in C<system()>.
 
+=item * dry_run => bool
+
+See option documentation in C<system()>.
+
 =back
 
 =head2 run([ \%opts ], @args)
@@ -501,6 +593,10 @@ Supply standard input.
 
 See option documentation in C<system()>.
 
+=item * dry_run => bool
+
+See option documentation in C<system()>.
+
 =back
 
 =head1 HOMEPAGE
